#-----------------------------------------------------------------------------
#
# ParaViewConfig.cmake - ParaView CMake configuration file for external projects.
#
# This file is configured by ParaView and used by the UseParaView.cmake module
# to load ParaView's settings for an external project.
set (__pv_install_tree TRUE)
if (__pv_install_tree)
  get_filename_component(location "${CMAKE_CURRENT_LIST_FILE}" PATH)
  set (VTK_CONFIG_FILE "${location}/VTKConfig.cmake")
  set (ParaView_CMAKE_DIR "${location}")
  set (PARAVIEW_CONFIG_TARGETS_FILE "${location}/ParaViewTargets.cmake")
else()
  # The ParaView is in the build-location.
  set (VTK_CONFIG_FILE "/builddir/build/BUILD/ParaView-3.98.1-source/fedora/VTK/VTKConfig.cmake")
  set (ParaView_CMAKE_DIR "/builddir/build/BUILD/ParaView-3.98.1-source/CMake")
  set (PARAVIEW_CONFIG_TARGETS_FILE "/builddir/build/BUILD/ParaView-3.98.1-source/fedora/ParaViewTargets.cmake")
endif()

#------------------------------------------------------------------------------
# Version information for ParaView
SET(PARAVIEW_VERSION_MAJOR "3")
SET(PARAVIEW_VERSION_MINOR "98")
SET(PARAVIEW_VERSION_PATCH "1")
SET(PARAVIEW_VERSION_FULL  "3.98.1")

# The location of the UseParaView.cmake file
# FIXME: I don't like this mixing of case, we need to fix that to be consistent.
set (ParaView_USE_FILE "${ParaView_CMAKE_DIR}/UseParaView.cmake")

set (PARAVIEW_USE_FILE ${ParaView_USE_FILE})
set (PARAVIEW_CMAKE_DIR ${ParaView_CMAKE_DIR})

# Import ParaView targets.
if(NOT TARGET vtkPVCommon)
  include("${PARAVIEW_CONFIG_TARGETS_FILE}")
endif()

# load VTK config. This will bring in information about all modules (including
# ParaView's modules).
include("${VTK_CONFIG_FILE}")

if (__pv_install_tree)
else()
  list(APPEND VTK_INCLUDE_DIRS "/builddir/build/BUILD/ParaView-3.98.1-source/fedora")
endif()

# unless using external vtk (when we start supporting it, that is)
# PARAVIEW_INCLUDE_DIRS is same as VTK_INCLUDE_DIRS, but to make it easier for
# ParaView users.
set (PARAVIEW_INCLUDE_DIRS ${VTK_INCLUDE_DIRS})

#------------------------------------------------------------------------------
# ParaView global configuration options.

set (PARAVIEW_BUILD_SHARED_LIBS "ON")
set (PARAVIEW_BUILD_QT_GUI "ON")
set (PARAVIEW_USE_MPI "OFF")
set (PARAVIEW_ENABLE_PYTHON "ON")
set (PARAVIEW_ENABLE_QT_SUPPORT "ON")
set (PARAVIEW_QT_QMAKE_EXECUTABLE "/usr/bin/qmake-qt4")
set (PARAVIEW_USE_VISITBRIDGE "OFF")
set (PARAVIEW_ENABLE_COPROCESSING "ON")

# cleanup
unset(__pv_install_tree)
